% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rsf_reg.R
\name{predict_rsf_reg}
\alias{predict_rsf_reg}
\title{Compute the prediction of a model built with \code{\link{rsf_reg}}}
\usage{
predict_rsf_reg(obj, newdata)
}
\arguments{
\item{obj}{A list output by \code{\link{rsf_reg}}}

\item{newdata}{A data.frame which contains the same variables as the ones
used for the training}
}
\value{
A list with the following elements :
\item{pred}{The vector of the predicted values for \code{phi}\eqn{(T')}
(with \eqn{T' = min(T, } \code{max_time}\eqn{)}) for the observations of \code{newdata}}
\item{surv}{The matrix which contains the estimated values of the survival curves at
\code{time_points}, for the observations of \code{newdata}}
\item{time_points}{The vector of the time points where the survival curves
are evaluated}
}
\description{
Given a model built wtih \code{\link{rsf_reg}},
\code{predict_rsf_reg} allows to get the predictions of the model for new
observations
}
\examples{

data("transplant", package = "survival")
transplant$delta = 1 * (transplant$event == "ltx") # create binary var
# which indicate censoring/non censoring

# keep only rows with no missing value
transplant_bis = transplant[stats::complete.cases(transplant),]


# ------------------------------------------------
#   Basic call to train a model
# ------------------------------------------------

set.seed(17)
train_lines = sample(1:nrow(transplant_bis), 600)
res1 = rsf_reg(y_var = "futime",
                      delta_var = "delta",
                      x_vars = setdiff(colnames(transplant_bis),c("futime", "delta", "event")),
                      train = transplant_bis[train_lines,],
                      types_w_ev = c("KM", "Cox", "RSF", "unif"))

# ------------------------------------------------
#   Predict on new data
# ------------------------------------------------

pred1 = predict_rsf_reg(obj = res1,
                       newdata = transplant_bis[-train_lines,])
print(pred1$pred[1:30])
}
\seealso{
\code{\link{rsf_reg}}
}
